diff --git a/samples/bluetooth/peripheral_uart/src/main.c b/samples/bluetooth/peripheral_uart/src/main.c
index d8afb44ca..bb93b71f4 100644
--- a/samples/bluetooth/peripheral_uart/src/main.c
+++ b/samples/bluetooth/peripheral_uart/src/main.c
@@ -62,6 +62,12 @@ static struct bt_conn *auth_conn;
 static const struct device *uart = DEVICE_DT_GET(DT_CHOSEN(nordic_nus_uart));
 static struct k_work_delayable uart_work;
 
+struct uart_data_rx_t {
+	void *fifo_reserved;
+	uint8_t data[1];
+	uint16_t len;
+};
+
 struct uart_data_t {
 	void *fifo_reserved;
 	uint8_t data[UART_BUF_SIZE];
@@ -92,6 +98,7 @@ static void uart_cb(const struct device *dev, struct uart_event *evt, void *user
 
 	static size_t aborted_len;
 	struct uart_data_t *buf;
+	struct uart_data_rx_t *buf_rx;
 	static uint8_t *aborted_buf;
 	static bool disable_req;
 
@@ -128,15 +135,16 @@ static void uart_cb(const struct device *dev, struct uart_event *evt, void *user
 
 	case UART_RX_RDY:
 		LOG_DBG("UART_RX_RDY");
-		buf = CONTAINER_OF(evt->data.rx.buf, struct uart_data_t, data);
-		buf->len += evt->data.rx.len;
+		buf_rx = CONTAINER_OF(evt->data.rx.buf, struct uart_data_rx_t, data);
+		buf_rx->len += evt->data.rx.len;
+		LOG_INF("UART RX: offset: %d, len: %d", evt->data.rx.offset, evt->data.rx.len);
 
 		if (disable_req) {
 			return;
 		}
 
-		if ((evt->data.rx.buf[buf->len - 1] == '\n') ||
-		    (evt->data.rx.buf[buf->len - 1] == '\r')) {
+		if ((evt->data.rx.buf[buf_rx->len - 1] == '\n') ||
+		    (evt->data.rx.buf[buf_rx->len - 1] == '\r')) {
 			disable_req = true;
 			uart_rx_disable(uart);
 		}
@@ -147,26 +155,26 @@ static void uart_cb(const struct device *dev, struct uart_event *evt, void *user
 		LOG_DBG("UART_RX_DISABLED");
 		disable_req = false;
 
-		buf = k_malloc(sizeof(*buf));
-		if (buf) {
-			buf->len = 0;
+		buf_rx = k_malloc(sizeof(*buf));
+		if (buf_rx) {
+			buf_rx->len = 0;
 		} else {
 			LOG_WRN("Not able to allocate UART receive buffer");
 			k_work_reschedule(&uart_work, UART_WAIT_FOR_BUF_DELAY);
 			return;
 		}
 
-		uart_rx_enable(uart, buf->data, sizeof(buf->data),
+		uart_rx_enable(uart, buf_rx->data, sizeof(buf_rx->data),
 			       UART_WAIT_FOR_RX);
 
 		break;
 
 	case UART_RX_BUF_REQUEST:
 		LOG_DBG("UART_RX_BUF_REQUEST");
-		buf = k_malloc(sizeof(*buf));
-		if (buf) {
-			buf->len = 0;
-			uart_rx_buf_rsp(uart, buf->data, sizeof(buf->data));
+		buf_rx = k_malloc(sizeof(*buf_rx));
+		if (buf_rx) {
+			buf_rx->len = 0;
+			uart_rx_buf_rsp(uart, buf_rx->data, sizeof(buf_rx->data));
 		} else {
 			LOG_WRN("Not able to allocate UART receive buffer");
 		}
@@ -175,13 +183,13 @@ static void uart_cb(const struct device *dev, struct uart_event *evt, void *user
 
 	case UART_RX_BUF_RELEASED:
 		LOG_DBG("UART_RX_BUF_RELEASED");
-		buf = CONTAINER_OF(evt->data.rx_buf.buf, struct uart_data_t,
+		buf_rx = CONTAINER_OF(evt->data.rx_buf.buf, struct uart_data_rx_t,
 				   data);
 
-		if (buf->len > 0) {
-			k_fifo_put(&fifo_uart_rx_data, buf);
+		if (buf_rx->len > 0) {
+			k_fifo_put(&fifo_uart_rx_data, buf_rx);
 		} else {
-			k_free(buf);
+			k_free(buf_rx);
 		}
 
 		break;
@@ -208,18 +216,18 @@ static void uart_cb(const struct device *dev, struct uart_event *evt, void *user
 
 static void uart_work_handler(struct k_work *item)
 {
-	struct uart_data_t *buf;
+	struct uart_data_rx_t *buf_rx;
 
-	buf = k_malloc(sizeof(*buf));
-	if (buf) {
-		buf->len = 0;
+	buf_rx = k_malloc(sizeof(*buf_rx));
+	if (buf_rx) {
+		buf_rx->len = 0;
 	} else {
 		LOG_WRN("Not able to allocate UART receive buffer");
 		k_work_reschedule(&uart_work, UART_WAIT_FOR_BUF_DELAY);
 		return;
 	}
 
-	uart_rx_enable(uart, buf->data, sizeof(buf->data), UART_WAIT_FOR_RX);
+	uart_rx_enable(uart, buf_rx->data, sizeof(buf_rx->data), UART_WAIT_FOR_RX);
 }
 
 static bool uart_test_async_api(const struct device *dev)
@@ -234,7 +242,7 @@ static int uart_init(void)
 {
 	int err;
 	int pos;
-	struct uart_data_t *rx;
+	struct uart_data_rx_t *rx;
 	struct uart_data_t *tx;
 
 	if (!device_is_ready(uart)) {
